@@ -1,18 +1,28 @@
 from django.conf import settings
-from django.contrib.syndication.feeds import Feed, FeedDoesNotExist
+from django.contrib.syndication.views import Feed, FeedDoesNotExist
 from django.contrib.sites.models import Site
 from django.core.cache import cache
 from django.core.urlresolvers import reverse
-from articles.models import Article, Tag
+from django.utils.feedgenerator import Atom1Feed
 
-SITE = Site.objects.get_current()
+from articles.models import Article, Tag
 
 # default to 24 hours for feed caching
 FEED_TIMEOUT = getattr(settings, 'ARTICLE_FEED_TIMEOUT', 86400)
 
-class LatestEntries(Feed):
+class SiteMixin(object):
+
+    @property
+    def site(self):
+        if not hasattr(self, '_site'):
+            self._site = Site.objects.get_current()
+
+        return self._site
+
+class LatestEntries(Feed, SiteMixin):
+
     def title(self):
-        return "%s Articles" % SITE.name
+        return "%s Articles" % (self.site.name,)
 
     def link(self):
         return reverse('articles_archive')
@@ -30,25 +40,21 @@ class LatestEntries(Feed):
     def item_author_name(self, item):
         return item.author.username
 
-    def item_tags(self, item):
-        return [c.name for c in item.tags.all()] + [keyword.strip() for keyword in item.keywords.split(',')]
-
     def item_pubdate(self, item):
         return item.publish_date
 
-class TagFeed(Feed):
-    def get_object(self, bits):
-        if len(bits) != 1:
-            raise FeedDoesNotExist
+class TagFeed(Feed, SiteMixin):
 
-        return Tag.objects.get(name__iexact=bits[0])
+    def get_object(self, request, slug):
+        try:
+            return Tag.objects.get(slug__iexact=slug)
+        except Tag.DoesNotExist:
+            raise FeedDoesNotExist
 
     def title(self, obj):
-        return "%s: Newest Articles Tagged '%s'" % (SITE.name, obj.name)
+        return "%s: Newest Articles Tagged '%s'" % (self.site.name, obj.name)
 
     def link(self, obj):
-        if not obj:
-            raise FeedDoesNotExist
         return obj.get_absolute_url()
 
     def description(self, obj):
@@ -76,3 +82,8 @@ class TagFeed(Feed):
     def item_pubdate(self, item):
         return item.publish_date
 
+class LatestEntriesAtom(LatestEntries):
+    feed_type = Atom1Feed
+
+class TagFeedAtom(TagFeed):
+    feed_type = Atom1Feed
