@@ -1,7 +1,26 @@
+import logging
+
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 from models import Article, Tag
 
+log = logging.getLogger('articles.forms')
+
+def tag(name):
+    """Returns a Tag object for the given name"""
+
+    slug = Tag.clean_tag(name)
+
+    log.debug('Looking for Tag with slug "%s"...' % (slug,))
+    t, created = Tag.objects.get_or_create(slug=slug, defaults={'name': name})
+    log.debug('Found Tag %s. Name: %s Slug: %s Created: %s' % (t.pk, t.name, t.slug, created))
+
+    if not t.name:
+        t.name = name
+        t.save()
+
+    return t
+
 class ArticleAdminForm(forms.ModelForm):
     tags = forms.CharField(initial='', required=False,
                            widget=forms.TextInput(attrs={'size': 100}),
@@ -21,8 +40,9 @@ class ArticleAdminForm(forms.ModelForm):
     def clean_tags(self):
         """Turns the string of tags into a list"""
 
-        tag = lambda n: Tag.objects.get_or_create(name=Tag.clean(n))[0]
-        tags = [tag(t) for t in self.cleaned_data['tags'].split()]
+        tags = [tag(t.strip()) for t in self.cleaned_data['tags'].split() if len(t.strip())]
+
+        log.debug('Tagging Article %s with: %s' % (self.cleaned_data['title'], tags))
         self.cleaned_data['tags'] = tags
         return self.cleaned_data['tags']
 
@@ -31,12 +51,12 @@ class ArticleAdminForm(forms.ModelForm):
 
     class Media:
         css = {
-            'all': ('css/jquery.autocomplete.css',),
+            'all': ('/css/jquery.autocomplete.css',),
         }
         js = (
-            'js/jquery-1.4.1.min.js',
-            'js/jquery.bgiframe.min.js',
-            'js/jquery.autocomplete.pack.js',
-            'js/tag_autocomplete.js',
+            '/js/jquery-1.4.1.min.js',
+            '/js/jquery.bgiframe.min.js',
+            '/js/jquery.autocomplete.pack.js',
+            '/js/tag_autocomplete.js',
         )
 
