@@ -75,7 +75,7 @@ class GetArticlesNode(template.Node):
             articles = articles[(int(self.start) - 1):int(self.end)]
 
         # don't send back a list when we really don't need/want one
-        if len(articles) == 1 and int(self.count) == 1 and not self.start:
+        if len(articles) == 1 and not self.start and int(self.count) == 1:
             articles = articles[0]
 
         # put the article(s) into the context
@@ -231,7 +231,7 @@ class GetPageURLNode(template.Node):
         try:
             # determine what view we are using based upon the path of this page
             view, args, kwargs = resolve(context['request'].path)
-        except (Resolver404, KeyError):
+        except (Resolver404, KeyError) as err:
             raise ValueError('Invalid pagination page.')
         else:
             # set the page parameter for this view
@@ -266,13 +266,6 @@ def get_page_url(parser, token):
 
     return GetPageURLNode(args[1], varname)
 
-class TagCloudNode(template.Node):
-    def __init__(self, varname):
-        self.varname = varname
-
-    def render(self, context):
-        context[self.varname] = tags
-
 def tag_cloud():
     """Provides the tags with a "weight" attribute to build a tag cloud"""
 
