@@ -1,3 +1,5 @@
+import logging
+
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.core.cache import cache
@@ -11,6 +13,8 @@ from datetime import datetime
 
 ARTICLE_PAGINATION = getattr(settings, 'ARTICLE_PAGINATION', 20)
 
+log = logging.getLogger('articles.views')
+
 def display_blog_page(request, tag=None, username=None, year=None, month=None, page=1):
     """
     Handles all of the magic behind the pages that list articles in any way.
@@ -18,17 +22,22 @@ def display_blog_page(request, tag=None, username=None, year=None, month=None, p
     than duplicate a bunch of code.  I'll probably revisit this in the future.
     """
 
-    context = {}
+    context = {'request': request}
     if tag:
-        tag = get_object_or_404(Tag, name__iexact=tag)
-        articles = tag.article_set.active().select_related()
+        try:
+            tag = get_object_or_404(Tag, slug__iexact=tag)
+        except Http404:
+            # for backwards-compatibility
+            tag = get_object_or_404(Tag, name__iexact=tag)
+
+        articles = tag.article_set.live(user=request.user).select_related()
         template = 'articles/display_tag.html'
         context['tag'] = tag
 
     elif username:
         # listing articles by a particular author
         user = get_object_or_404(User, username=username)
-        articles = user.article_set.active()
+        articles = user.article_set.live(user=request.user)
         template = 'articles/by_author.html'
         context['author'] = user
 
@@ -36,13 +45,13 @@ def display_blog_page(request, tag=None, username=None, year=None, month=None, p
         # listing articles in a given month and year
         year = int(year)
         month = int(month)
-        articles = Article.objects.active().select_related().filter(publish_date__year=year, publish_date__month=month)
+        articles = Article.objects.live(user=request.user).select_related().filter(publish_date__year=year, publish_date__month=month)
         template = 'articles/in_month.html'
         context['month'] = datetime(year, month, 1)
 
     else:
         # listing articles with no particular filtering
-        articles = Article.objects.active()
+        articles = Article.objects.live(user=request.user)
         template = 'articles/article_list.html'
 
     # paginate the articles
@@ -64,7 +73,7 @@ def display_article(request, year, slug, template='articles/article_detail.html'
     """Displays a single article."""
 
     try:
-        article = Article.objects.active().get(publish_date__year=year, slug=slug)
+        article = Article.objects.live(user=request.user).get(publish_date__year=year, slug=slug)
     except Article.DoesNotExist:
         raise Http404
 
